GAP based TOF Demo

Dependencies:   BLE_API X_NUCLEO_6180XA1 mbed

Fork of BLE_HeartRate_IDB0XA1 by ST

Revision:
25:231d3f382583
Parent:
24:0f08f68579bd
Child:
26:fd06c8b57d16
--- a/bricks/service.h	Fri Jan 06 20:49:58 2017 +0000
+++ b/bricks/service.h	Fri Jan 06 21:36:47 2017 +0000
@@ -72,7 +72,7 @@
              collection.add(pChr);
          }
          
-         void config(Blob &blue)            // configure the service
+         void enroll(Blob &blue)            // enroll the service
          {
             static const uint16_t list[] = {0xFFFF};